---
name: "\U0001F41B Bug Report"
about: If something isn't working as expected.
title: ''
labels: ''
assignees: ''

---

## BUG/PROBLEM REPORT (OR OTHER COMMON ISSUE)

<!--

Read https://github.com/edutap-eu/edutap.wallet_google/blob/main/CONTRIBUTING.md

Please include tracebacks, screenshots, Jupyter notebooks, code of debugging sessions or code that reproduces the issue if possible.
The best reproductions are in plain `.venv` installations without plug-ins or at least with minimal needed integrations installed.

-->

### What I did:

<!-- Please a reproducible description, including preconditions. -->

### What I expect to happen:

<!-- Please tell us what the expected result is. -->

### What actually happened:

<!-- Please tell us the actual result. -->

### Versions used:

<!--
What versions of Python, edutap.wallet_google, plug-ins were used?
What Operating System and version were used?
-->
